@@ -58,19 +58,20 @@ class loadOneByOneDataset(data.Dataset):
                         ntext_arr = [ntext.strip() for ntext in negative_text.split("[SEP]")]
                     else:
                         ntext_arr = [negative_text.strip()]
-                    for neg_text in ntext_arr:
-                        if 'pos' in likelihood:
-                            feature = gen_once.data_loader.get_feature_from_data(tokenizer, maxlen, input,
-                                                                                 " ".join(target))
-                        elif 'neg' in likelihood:
-                            feature = gen_once.data_loader.get_feature_from_data(tokenizer, maxlen, input,
-                                                                                 ntarget=neg_text)
-                        elif 'both' in likelihood:
-                            feature = gen_once.data_loader.get_feature_from_data(tokenizer, maxlen, input,
-                                                                                 " ".join(target),
-                                                                                 ntarget=neg_text)
-                        if len(feature['input']) == len(feature['target']) == len(feature['ntarget']) == maxlen:
-                            sample.append(feature)
+                    for _ in range(len(tokenized_target) + 1):
+                        for neg_text in ntext_arr:
+                            if 'pos' in likelihood:
+                                feature = gen_once.data_loader.get_feature_from_data(tokenizer, maxlen, input,
+                                                                                     " ".join(target))
+                            elif 'neg' in likelihood:
+                                feature = gen_once.data_loader.get_feature_from_data(tokenizer, maxlen, input,
+                                                                                     ntarget=neg_text)
+                            elif 'both' in likelihood:
+                                feature = gen_once.data_loader.get_feature_from_data(tokenizer, maxlen, input,
+                                                                                     " ".join(target),
+                                                                                     ntarget=neg_text)
+                            if len(feature['input']) == len(feature['target']) == len(feature['ntarget']) == maxlen:
+                                sample.append(feature)
 
             if cache:
                 with open(cache_path, 'wb') as cf:
